! 2017_04_05 Author: J Perez-Losada
! This program computes the values of tF for languages in each distance 1000-km interval.

program PLOS_One_Response

implicit none

integer:: ii,ijk,jj

integer:: ntotal                 ! Number of points in input file. For t = 2280 gen, 10 tribes, ntotal = 5010 
parameter (ntotal=5010)    

character(3)  name_start(ntotal) ! Name of the language (3 letters).

integer:: phone_world            ! Total number of phonemes (908)
parameter (phone_world = 908)     
integer:: delta                  ! Delta step = 1000 km
parameter (delta = 1000)
integer:: n_delta                ! Numer of steps
parameter (n_delta = 25)
integer:: phone_delta(26)        ! Number of steps 25 + 1 (i.e. 25 intervals 26 points)

real*8  ax(ntotal,phone_world)
real*4  cont_po(phone_world)
real*4  distance(ntotal)         ! Distance from UPSID database after Atkinson (2011)
real*4  tf, sum_po               ! tF
 
    open (20,file= 'tfdelta1.txt',status='unknown')  ! Input  file
    open (50,file= 'tf_bin.txt'  ,status='unknown')  ! Output file
    write(50,*) " Y(km) node  min    max   Tf  "
    
    ax  = 0.0d0
    
    do ijk = 1,ntotal
        read(20,*) (ax(ijk,ii),ii=1,phone_world), name_start(ijk), distance(ijk)     ! Read sequence of 1 and 0        
        write(*,*) ijk, name_start(ijk), distance(ijk)
    enddo  ! ijk
    close(20)
 
    phone_delta = 0
    ijk = 1

    do jj = 1, n_delta                                ! Counts the number of languages in each interval       
        do while ((distance(ijk).lt.jj*delta).and.(ijk.lt.ntotal))
            ijk = ijk + 1
        enddo
        phone_delta(jj+1)=ijk-1 
    enddo ! jj

    phone_delta(jj) = ntotal 

!   
!************** Initial Total Tf ***********************************************
!
    do jj = 1,n_delta     

    sum_po  = 0d0
    cont_po = 0.0d0

    do ii = 1, phone_world
        do ijk = phone_delta(jj)+1, phone_delta(jj+1) 
            if(ax(ijk,ii).eq.1.0) cont_po(ii) = cont_po(ii) + 1
        enddo
        sum_po = sum_po + cont_po(ii)          ! Total number of data points
    enddo
    
    do ii = 1, phone_world       
        cont_po(ii) = (cont_po(ii)/sum_po)**2  ! Relative frequencies
    enddo
    sum_po = 0.0d0
    do ii = 1, phone_world       
        sum_po = sum_po + cont_po(ii)
    enddo

    tf = (1.0d0/sum_po)-1.0d0                  ! Tf as defined in Newman, F.(1995)
     
    write(50,50) int(jj*delta),jj,phone_delta(jj)+1, phone_delta(jj+1), tf

50  format(i6,x,i3,x,i6,x,i6,f7.2) 
    
    enddo ! jj 

end program
    
